using Dynamicweb.Ecommerce.LiveIntegration.Configuration;
using Dynamicweb.Extensibility.Notifications;

namespace Dynamicweb.Ecommerce.LiveIntegration.NotificationSubscribers
{
    /// <summary>
    /// Adds a global template tag to indicate the status of the web service connection.
    /// </summary>
    /// <seealso cref="NotificationSubscriberBase" />
    [Subscribe(Dynamicweb.Notifications.Standard.Page.OnGlobalTags)]
    public class PageOnGlobalTags : NotificationSubscriberBase
    {
        /// <summary>
        /// Handles the notification.
        /// </summary>
        /// <param name="notification">The notification.</param>
        /// <param name="args">The args.</param>
        public override void OnNotify(string notification, NotificationArgs args)
        {
            Dynamicweb.Notifications.Standard.Page.PageviewNotificationArgs pageviewNotificationArgs = args as Dynamicweb.Notifications.Standard.Page.PageviewNotificationArgs;
            if (pageviewNotificationArgs != null)
            {
                string globalTagName = Settings.Instance.WebServiceConnectionStatusGlobalTagName;
                if (!string.IsNullOrEmpty(globalTagName))
                {
                    if (EnabledAndActive())
                    {
                        pageviewNotificationArgs.Template.SetTag(globalTagName, Connector.IsWebServiceConnectionAvailable().ToString().ToLower());
                        pageviewNotificationArgs.Template.SetTag("Global:LiveIntegration.IsLazyLoadingForProductInfoEnabled", TemplatesHelper.IsLazyLoadingForProductInfoEnabled.ToString().ToLower());
                    }
                }
            }
        }
    }
}